@@ -15,7 +15,7 @@ class ContactIndexer : public AbstractIndexer
 {
 public:
     explicit ContactIndexer(const QString &path);
-    ~ContactIndexer();
+    ~ContactIndexer() override;
 
     QStringList mimeTypes() const override;
 
@@ -26,6 +26,7 @@ public:
     void commit() override;
 
     void move(Akonadi::Item::Id itemId, Akonadi::Collection::Id from, Akonadi::Collection::Id to) override;
+
 private:
     bool indexContact(const Akonadi::Item &item);
     void indexContactGroup(const Akonadi::Item &item);
