@@ -9,12 +9,15 @@
 #ifndef AKONADI_SEARCH_PIM_CONTACTCOMPLETER_H
 #define AKONADI_SEARCH_PIM_CONTACTCOMPLETER_H
 
-#include <QString>
 #include "search_pim_export.h"
+#include <QString>
 
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
 // FIXME: Make this async!!
 /** Contact completer. */
 class AKONADI_SEARCH_PIM_EXPORT ContactCompleter
@@ -22,11 +25,11 @@ class AKONADI_SEARCH_PIM_EXPORT ContactCompleter
 public:
     explicit ContactCompleter(const QString &prefix, int limit = 10);
 
-    QStringList complete();
+    Q_REQUIRED_RESULT QStringList complete();
 
 private:
-    QString m_prefix;
-    int m_limit;
+    const QString m_prefix;
+    const int m_limit;
 };
 }
 }
