@@ -11,8 +11,10 @@
 
 #include <xapian.h>
 
-namespace Akonadi {
-namespace Search {
+namespace Akonadi
+{
+namespace Search
+{
 class AgePostingSource : public Xapian::ValuePostingSource
 {
 public:
