@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -11,8 +11,10 @@
 
 #include "../pimsearchstore.h"
 
-namespace Akonadi {
-namespace Search {
+namespace Akonadi
+{
+namespace Search
+{
 class NoteSearchStore : public PIMSearchStore
 {
     Q_OBJECT
